==> jc-1.4.0.tar.gz: scm/Div.h <==
// class scm.Div

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fa8a70c9bd50ce92 scm_Div
// @dep_class 6d0a82a28dffac88 scm_Procedure

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_Div_H_
#define _JC_scm_Div_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_Div$sub_refs	_jc_scm_Div$sub_refs;
typedef struct _jc_scm_Div$sub_nonrefs	_jc_scm_Div$sub_nonrefs;
typedef struct _jc_scm_Div$refs	_jc_scm_Div$refs;
typedef struct _jc_scm_Div$nonrefs	_jc_scm_Div$nonrefs;
typedef struct _jc_scm_Div$object	_jc_scm_Div$object;

typedef const struct _jc_scm_Div$vmethods	_jc_scm_Div$vmethods;
typedef const struct _jc_scm_Div$vtable	_jc_scm_Div$vtable;
typedef const struct _jc_scm_Div$vtype	_jc_scm_Div$vtype;

// Constructors
extern void _jc_scm_Div$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_Div$object *);

// Virtual methods
extern struct _jc_object *_jc_scm_Div$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_Div$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
extern struct _jc_java_lang_String$object *_jc_scm_Div$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_Div$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_Div$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_Div$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_Div$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_Div$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_Div$object *);
};

// Vtable
struct _jc_scm_Div$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_Div$vmethods	scm_Div;
};

// Vtype
struct _jc_scm_Div$vtype {
	_jc_type			type;
	_jc_scm_Div$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_Div$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_Div$refs {
    _jc_scm_Div$sub_refs	scm_Div;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_Div$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_Div$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_Div$sub_nonrefs	scm_Div;
};

// Object instance structure
struct _jc_scm_Div$object {
	_jc_scm_Div$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_Div$vtype	*vtype;
	_jc_scm_Div$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_Div$vtype _jc_scm_Div$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_Div, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_Div$class_object;

#endif	/* _JC_scm_Div_H_ */

==> jc-1.4.6.tar.gz: scm/Div.h <==
// class scm.Div

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fa8a70c9bd50ce92 scm_Div
// @dep_class 6d0a82a28dffac88 scm_Procedure

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_Div_H_
#define _JC_scm_Div_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_Div$sub_refs	_jc_scm_Div$sub_refs;
typedef struct _jc_scm_Div$sub_nonrefs	_jc_scm_Div$sub_nonrefs;
typedef struct _jc_scm_Div$refs	_jc_scm_Div$refs;
typedef struct _jc_scm_Div$nonrefs	_jc_scm_Div$nonrefs;
typedef struct _jc_scm_Div$object	_jc_scm_Div$object;

typedef const struct _jc_scm_Div$vmethods	_jc_scm_Div$vmethods;
typedef const struct _jc_scm_Div$vtable	_jc_scm_Div$vtable;
typedef const struct _jc_scm_Div$vtype	_jc_scm_Div$vtype;

// Constructors
extern void _jc_scm_Div$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_Div$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_Div$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_Div$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_Div$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_Div$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_Div$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_Div$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_Div$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_Div$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_Div$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_Div$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_Div$vmethods	scm_Div;
};

// Vtype
struct _jc_scm_Div$vtype {
	_jc_type			type;
	_jc_scm_Div$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_Div$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_Div$refs {
    _jc_scm_Div$sub_refs	scm_Div;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_Div$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_Div$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_Div$sub_nonrefs	scm_Div;
};

// Object instance structure
struct _jc_scm_Div$object {
	_jc_scm_Div$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_Div$vtype	*vtype;
	_jc_scm_Div$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_Div$vtype _jc_scm_Div$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_Div, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_Div$class_object;

#endif	/* _JC_scm_Div_H_ */
